# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-14 11:12
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Bibliography',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('source', models.CharField(choices=[('PM', 'PubMed article'), ('PT', 'Patent')], max_length=2, verbose_name='Bibliographic type')),
                ('id_source', models.CharField(max_length=25, verbose_name='Bibliographic ID')),
                ('title', models.CharField(max_length=300, verbose_name='Title')),
                ('journal_name', models.CharField(max_length=50, verbose_name='Journal name')),
                ('authors_list', models.CharField(max_length=500, verbose_name='Authors list')),
                ('biblio_year', models.PositiveSmallIntegerField(verbose_name='Year')),
                ('cytotox', models.BooleanField(verbose_name='Cytotoxicity data')),
                ('in_silico', models.BooleanField(verbose_name='in silico study performed')),
                ('in_vitro', models.BooleanField(verbose_name='in vitro study performed')),
                ('in_vivo', models.BooleanField(verbose_name='in vivo study performed')),
                ('in_cellulo', models.BooleanField(verbose_name='in cellulo study performed')),
                ('pharmacokinetic', models.BooleanField(verbose_name='pharmacokinetic study performed')),
                ('xray', models.BooleanField(verbose_name='contains xray data')),
            ],
        ),
        migrations.CreateModel(
            name='BindingSite',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
        ),
        migrations.CreateModel(
            name='Complex',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('copy_nb', models.IntegerField(verbose_name='Number of copies')),
            ],
        ),
        migrations.CreateModel(
            name='Domain',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('pfam_acc', models.CharField(max_length=10, unique=True, verbose_name='Pfam Accession')),
                ('pfam_id', models.CharField(max_length=20, verbose_name='Pfam Family Identifier')),
                ('pfam_description', models.CharField(max_length=100, verbose_name='Pfam Description')),
                ('domainfamily', models.CharField(max_length=25, verbose_name='')),
            ],
        ),
        migrations.CreateModel(
            name='MolecularFunction',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('go_id', models.CharField(max_length=10, unique=True, verbose_name='Gene Ontology ID')),
                ('description', models.CharField(max_length=500, verbose_name='description')),
            ],
        ),
        migrations.CreateModel(
            name='Ppi',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('binding_site_id_1', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='binding_site_id_1', to='ippidb.BindingSite')),
                ('binding_site_id_2', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='binding_site_id_2', to='ippidb.BindingSite')),
                ('complex_id_1', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='cplx_id_1', to='ippidb.Complex')),
                ('complex_id_2', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='cplx_id_2', to='ippidb.Complex')),
            ],
        ),
        migrations.CreateModel(
            name='PpiArchitecture',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('pdb_id', models.CharField(max_length=4, verbose_name='PDB ID')),
                ('ppi_id', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='ippidb.Ppi')),
            ],
        ),
        migrations.CreateModel(
            name='Protein',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('uniprot_id', models.CharField(max_length=10, unique=True, verbose_name='Uniprot ID')),
                ('recommended_name_long', models.CharField(max_length=75, verbose_name='Uniprot Recommended Name (long)')),
                ('short_name', models.CharField(max_length=50, verbose_name='Short name')),
                ('gene_name', models.CharField(max_length=30, unique=True, verbose_name='Gene name')),
                ('entry_name', models.CharField(max_length=30, verbose_name='Entry name')),
                ('molecular_functions', models.ManyToManyField(to='ippidb.MolecularFunction')),
            ],
        ),
        migrations.CreateModel(
            name='Taxonomy',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('taxonomy_id', models.DecimalField(decimal_places=0, max_digits=4, unique=True, verbose_name='NCBI TaxID')),
                ('name', models.CharField(max_length=200, verbose_name='Organism name')),
            ],
        ),
        migrations.AddField(
            model_name='protein',
            name='organism',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='ippidb.Taxonomy'),
        ),
        migrations.AddField(
            model_name='complex',
            name='protein_id',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='ippidb.Protein'),
        ),
        migrations.AddField(
            model_name='bindingsite',
            name='domain_id',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='ippidb.Domain'),
        ),
        migrations.AddField(
            model_name='bindingsite',
            name='protein_id',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='ippidb.Protein'),
        ),
    ]
